==> myfaces-tobago-1.5.13-dist.tar.gz: org/apache/myfaces/tobago/model/WizardStep.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.model;

/**
 * Date: 15.05.2008 09:33:43
 */

public class WizardStep {

  private String outcome;
  private String title;
  private int index;

  public WizardStep(int index) {
    this.index = index;
  }

  public String getOutcome() {
    return outcome;
  }

  public void setOutcome(String outcome) {
    this.outcome = outcome;
  }

  public String getTitle() {
    return title;
  }

  public void setTitle(String title) {
    this.title = title;
  }

  public int getIndex() {
    return index;
  }

  public void setIndex(int index) {
    this.index = index;
  }

  public String toString() {
    StringBuilder builder = new StringBuilder();
    builder.append("#");
    builder.append(index);
    builder.append(" outcome='");
    builder.append(outcome);
    builder.append("' title='");
    builder.append(title);
    builder.append("'");
    return builder.toString();
  }
}

==> myfaces-tobago-2.5.3-dist.tar.gz: org/apache/myfaces/tobago/model/WizardStep.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.model;

public class WizardStep {

  private String outcome;
  private String title;
  private int index;

  public WizardStep(final int index) {
    this.index = index;
  }

  public String getOutcome() {
    return outcome;
  }

  public void setOutcome(final String outcome) {
    this.outcome = outcome;
  }

  public String getTitle() {
    return title;
  }

  public void setTitle(final String title) {
    this.title = title;
  }

  public int getIndex() {
    return index;
  }

  public void setIndex(final int index) {
    this.index = index;
  }

  public String toString() {
    final StringBuilder builder = new StringBuilder();
    builder.append("#");
    builder.append(index);
    builder.append(" outcome='");
    builder.append(outcome);
    builder.append("' title='");
    builder.append(title);
    builder.append("'");
    return builder.toString();
  }
}
